@@ -40,9 +40,10 @@
 #'
 #' \bold{Output:} \tab \cr
 #' \cr
-#' \code{A} \tab photosynthetic rate at \code{C_chl} (\eqn{\mu}mol CO2 / (m\eqn{^2} s)) \cr
-#' \code{C_chl} \tab chloroplastic CO2 concentration where \code{A_supply} intersects \code{A_demand} (Pa) \cr
-#' \code{g_tc} \tab total conductance to CO2 at \code{T_leaf} (\eqn{\mu}mol CO2 / (m\eqn{^2} s)) \cr
+#' \code{A} \tab photosynthetic rate at \code{C_chl} (\eqn{\mu}mol CO2 / m\eqn{^2} / s) \cr
+#' \code{C_chl} \tab chloroplastic CO2 concentration where \code{A_supply} intersects \code{A_demand} (\eqn{mu}mol / mol) \cr
+#' \code{C_i} \tab intercellular CO2 concentration where \code{A_supply} intersects \code{A_demand} (\eqn{mu}mol / mol) \cr
+#' \code{g_tc} \tab total conductance to CO2 at \code{T_leaf} (mol / m\eqn{^2} / s)) \cr
 #' \code{value} \tab \code{A_supply} - \code{A_demand} (\eqn{\mu}mol / (m\eqn{^2} s)) at \code{C_chl} \cr
 #' \code{convergence} \tab convergence code (0 = converged)
 #' }
@@ -375,7 +376,8 @@ photo = function(
   soln$C_chl %<>% set_units(umol / mol)
   soln$g_tc %<>% set_units(mol / m^2 / s)
   soln$A %<>% set_units(umol / m^2 / s)
-
+  soln$C_i = set_units(soln$C_air - soln$A / soln$g_sc, umol/mol)
+  
   soln
   
 }
@@ -439,8 +441,8 @@ add_Tleaf_photo = function(leaf_par, enviro_par, constants, prepare_for_tleaf) {
     set_units = TRUE
   ) %>% 
     dplyr::rename(
-      tealeaves_convergence = .data$convergence,
-      tealeaves_value = .data$value
+      tealeaves_convergence = "convergence",
+      tealeaves_value = "value"
     )
   leaf_par$T_leaf = tl$T_leaf
 
@@ -464,10 +466,14 @@ find_A = function(unitless_pars, quiet, use_legacy_version) {
 
   fit = tryCatch(
     {
+      Cchl_upper = max(c(unitless_pars$gamma_star, unitless_pars$C_air))
+      while (supply_minus_demand(Cchl_upper, unitless_pars, use_legacy_version) > 0) {
+        Cchl_upper = 2 * Cchl_upper
+      }
       stats::uniroot(supply_minus_demand,
         unitless_pars = unitless_pars, lower = 0.1,
-        upper = max(c(10, unitless_pars$C_air)), check.conv = TRUE,
-        use_legacy_version = use_legacy_version
+        upper = Cchl_upper, 
+        check.conv = TRUE, use_legacy_version = use_legacy_version
       )
     },
     finally = {
